:mod:`neuronvisio.controls` -- User Interface module
====================================================

.. automodule:: neuronvisio.controls
   
:class:`Controls`
-----------------

.. autoclass:: Controls
   :members:

:class:`Timeloop`
-----------------
   
.. autoclass:: Timeloop
   :members:
